body    {
        color:  black;
        background:     #F5F5E5;
	padding: 1ex;
	background-position: top right;
        }

h1	{
	text-align: center;
	font-family: serif;
	font-variant: small-caps;
	letter-spacing: 0.3em;
	font-size: 3em;
	}

h2	{
	color:	#881133;
	}

h2.menu	{
	color:	#6699BB;
	background: #E5FAFF;
	text-align: right;
	font-family: serif;
	font-size: 1.5em;
	font-variant: small-caps;
	padding-right: 1ex;
	}

body>div.hbar	{
	background:	#991111;
	width: 100%;
	height: 1ex;
	}

div.body	{
	margin-top: 1ex;
	padding-left: 1ex;
	padding-right: 1em;
	padding-top: 1em;
	padding-bottom: 1ex;
	margin-right: 26ex;
	}

div.menu	{
	background: 	#CCEEF5;
	margin-top: 	1ex;
	padding: 	1px 5px 2em;
	line-height: 	1.3;
	float: 	right;
	width: 	28ex;
	}

a:link	{
	font-weight: bold;
	}

a:active {
	text-decoration: overline;
	}

a:visited {
	font-weight: bold;
	}

@media print {
	div.menu {visibility: hidden}
	div.body {margin-right: 2ex}
	}
